==> qt4-x11_4.1.3.orig.tar.gz: qt-x11-opensource-src-4.1.3/src/qt3support/widgets/q3vbox.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
**
** This file is part of the Qt3Support module of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/


#include "q3vbox.h"

/*!
    \class Q3VBox qvbox.h
    \brief The Q3VBox widget provides vertical geometry management of
    its child widgets.

    \compat

    All its child widgets will be placed vertically and sized
    according to their sizeHint()s.

    \img qvbox-m.png Q3VBox

    \sa QHBox
*/


/*!
    Constructs a vbox widget called \a name with parent \a parent and
    widget flags \a f.
 */
Q3VBox::Q3VBox( QWidget *parent, const char *name, Qt::WFlags f )
    :Q3HBox( false, parent, name, f )
{
}

==> qt4-x11_4.2.0.orig.tar.gz: qt-x11-opensource-src-4.2.0/src/qt3support/widgets/q3vbox.cpp <==
/****************************************************************************
**
** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
**
** This file is part of the Qt3Support module of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License version 2.0 as published by the Free Software Foundation
** and appearing in the file LICENSE.GPL included in the packaging of
** this file.  Please review the following information to ensure GNU
** General Public Licensing requirements will be met:
** http://www.trolltech.com/products/qt/opensource.html
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/


#include "q3vbox.h"

/*!
    \class Q3VBox qvbox.h
    \brief The Q3VBox widget provides vertical geometry management of
    its child widgets.

    \compat

    All its child widgets will be placed vertically and sized
    according to their sizeHint()s.

    \img qvbox-m.png Q3VBox

    \sa QHBox
*/


/*!
    Constructs a vbox widget called \a name with parent \a parent and
    widget flags \a f.
 */
Q3VBox::Q3VBox( QWidget *parent, const char *name, Qt::WindowFlags f )
    :Q3HBox( false, parent, name, f )
{
}
